@@ -273,11 +273,11 @@ static char *next_line(char *p, const char *end)
 }
 
 static void *grab_module(const char *name, unsigned long *size, char**filename,
-	const char *kernel)
+	const char *kernel, const char *basedir)
 {
 	char *data;
 	struct utsname buf;
-	char *depname, *p;
+	char *depname, *p, *moddir;
 
 	data = grab_file(name, size);
 	if (data) {
@@ -290,14 +290,25 @@ static void *grab_module(const char *name, unsigned long *size, char**filename,
 		return NULL;
 	}
 
-	/* Search for it in modules.dep. */
 	if (kernel) {
-		asprintf(&depname, "%s/%s/modules.dep", MODULE_DIR, kernel);
+		if (strlen(basedir))
+			asprintf(&moddir, "%s/%s/%s",
+				basedir, MODULE_DIR, kernel);
+		else
+			asprintf(&moddir, "%s/%s",
+				MODULE_DIR, kernel);
 	} else {
 		uname(&buf);
-		asprintf(&depname, "%s/%s/modules.dep", MODULE_DIR,
-			 buf.release);
+		if (strlen(basedir))
+			asprintf(&moddir, "%s/%s/%s",
+			 	basedir, MODULE_DIR, buf.release);
+		else
+			asprintf(&moddir, "%s/%s",
+				MODULE_DIR, buf.release);
 	}
+	asprintf(&depname, "%s/%s", moddir, "modules.dep");
+
+	/* Search for it in modules.dep. */
 	data = grab_file(depname, size);
 	if (!data) {
 		fprintf(stderr, "modinfo: could not open %s\n", depname);
@@ -309,9 +320,25 @@ static void *grab_module(const char *name, unsigned long *size, char**filename,
 	for (p = data; p < data + *size; p = next_line(p, data + *size)) {
 		if (name_matches(p, data + *size, name)) {
 			int namelen = strcspn(p, ":");
-			*filename = malloc(namelen + 1);
-			memcpy(*filename, p, namelen);
-			(*filename)[namelen] = '\0';
+
+			if ('/' == p[0]) { /* old style deps - absolute path */
+				*filename = malloc(namelen + strlen(basedir)+2);
+				if (strlen(basedir)) {
+					sprintf(*filename, "%s/", basedir);
+					memcpy(*filename+strlen(basedir)+1,p,
+						namelen);
+					(*filename)[namelen
+						+strlen(basedir)+1] = '\0';
+				} else {
+					memcpy(*filename,p,namelen);
+					(*filename)[namelen] = '\0';
+				}
+			} else {
+				*filename = malloc(namelen + strlen(moddir)+2);
+				sprintf(*filename, "%s/", moddir);
+				memcpy(*filename+strlen(moddir)+1, p,namelen);
+				(*filename)[namelen+strlen(moddir)+1] ='\0';
+			}
 			release_file(data, *size);
 			data = grab_file(*filename, size);
 			if (!data)
@@ -328,11 +355,12 @@ static void *grab_module(const char *name, unsigned long *size, char**filename,
 
 static void usage(const char *name)
 {
-	fprintf(stderr, "Usage: %s [-0][-F field][-k kernelversion] module...\n"
+	fprintf(stderr, "Usage: %s [-0][-F field][-k kernelversion][-b basedir]  module...\n"
 		" Prints out the information about one or more module(s).\n"
 		" If a fieldname is given, just print out that field (or nothing if not found).\n"
 		" Otherwise, print all information out in a readable form\n"
-		" If -0 is given, separate with nul, not newline.\n",
+		" If -0 is given, separate with nul, not newline.\n"
+		" If -b is given, use an image of the module tree.\n",
 		name);
 }
 
@@ -344,6 +372,7 @@ int main(int argc, char *argv[])
 	char sep = '\n';
 	unsigned long infosize = 0;
 	int opt, ret = 0;
+	char *basedir = "";
 
 	if (!getenv("NEW_MODINFO"))
 		try_old_version("modinfo", argv);
@@ -354,7 +383,7 @@ int main(int argc, char *argv[])
 	else
 		abort();
 
-	while ((opt = getopt_long(argc,argv,"adlpVhn0F:k:",options,NULL)) >= 0){
+	while ((opt = getopt_long(argc,argv,"adlpVhn0F:k:b:",options,NULL)) >= 0){
 		switch (opt) {
 		case 'a': field = "author"; break;
 		case 'd': field = "description"; break;
@@ -365,6 +394,7 @@ int main(int argc, char *argv[])
 		case 'F': field = optarg; break;
 		case '0': sep = '\0'; break;
 		case 'k': kernel = optarg; break;
+		case 'b': basedir = optarg; break;
 		default:
 			usage(argv[0]); exit(0);
 		}
@@ -377,7 +407,8 @@ int main(int argc, char *argv[])
 		unsigned long modulesize;
 		char *filename;
 
-		mod = grab_module(argv[opt], &modulesize, &filename, kernel);
+		mod = grab_module(argv[opt], &modulesize, &filename,
+				  kernel, basedir);
 		if (!mod) {
 			ret = 1;
 			continue;
