@@ -46,7 +46,9 @@
 #include "logging.h"
 #include "index.h"
 #include "list.h"
-#include "backwards_compat.c"
+#include "config_filter.h"
+
+#include "testing.h"
 
 int use_binary_indexes = 1; /* default to enabled. */
 
@@ -74,7 +76,7 @@ static void grammar(const char *cmd, const char *filename, unsigned int line)
 static void print_usage(const char *progname)
 {
 	fprintf(stderr,
-		"Usage: %s [-v] [-V] [-C config-file] [-n] [-i] [-q] [-b] [-o <modname>] [ --dump-modversions ] <modname> [parameters...]\n"
+		"Usage: %s [-v] [-V] [-C config-file] [-d <dirname> ] [-n] [-i] [-q] [-b] [-o <modname>] [ --dump-modversions ] <modname> [parameters...]\n"
 		"%s -r [-n] [-i] [-v] <modulename> ...\n"
 		"%s -l -t <dirname> [ -a <modulename> ...]\n",
 		progname, progname, progname);
@@ -224,11 +226,12 @@ static int modname_equal(const char *a, const char *b, unsigned int len)
 /* Fills in list of modules if this is the line we want. */
 static int add_modules_dep_line(char *line,
 				const char *name,
-				struct list_head *list)
+				struct list_head *list,
+				const char *dirname)
 {
 	char *ptr;
 	int len;
-	char *modname;
+	char *modname, *fullpath;
 
 	/* Ignore lines without : or which start with a # */
 	ptr = strchr(line, ':');
@@ -249,7 +252,13 @@ static int add_modules_dep_line(char *line,
 		return 0;
 
 	/* Create the list. */
-	add_module(line, ptr - line, list);
+	if ('/' == line[0]) {	/* old style deps - absolute path specified */
+		add_module(line, ptr - line, list);
+	} else {
+		nofail_asprintf(&fullpath, "%s/%s", dirname, line);
+		add_module(fullpath, strlen(dirname)+1+(ptr - line), list);
+		free(fullpath);
+	}
 
 	ptr++;
 	for(;;) {
@@ -259,7 +268,14 @@ static int add_modules_dep_line(char *line,
 			break;
 		dep_start = ptr;
 		ptr += strcspn(ptr, " \t");
-		add_module(dep_start, ptr - dep_start, list);
+		if ('/' == dep_start[0]) {	/* old style deps */
+			add_module(dep_start, ptr - dep_start, list);
+		} else {
+			nofail_asprintf(&fullpath, "%s/%s", dirname, dep_start);
+			add_module(fullpath,
+				   strlen(dirname)+1+(ptr - dep_start), list);
+			free(fullpath);
+		}
 	}
 	return 1;
 }
@@ -272,7 +288,7 @@ static int read_depends_bin(const char *dirname,
 	char *line;
 	FILE *modules_dep;
 
-	asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep.bin");
+	nofail_asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep.bin");
 	modules_dep = fopen(modules_dep_name, "r");
 	if (!modules_dep) {
 		free(modules_dep_name);
@@ -282,7 +298,7 @@ static int read_depends_bin(const char *dirname,
 	line = index_search(modules_dep, start_name);
 	if (line) {
 		/* Value is standard dependency line format */
-		if (!add_modules_dep_line(line, start_name, list))
+		if (!add_modules_dep_line(line, start_name, list, dirname))
 			fatal("Module index is inconsistent\n");
 		free(line);
 	}
@@ -305,7 +321,7 @@ static void read_depends(const char *dirname,
 	if (read_depends_bin(dirname, start_name, list))
 		return;
 
-	asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep");
+	nofail_asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep");
 	modules_dep = fopen(modules_dep_name, "r");
 	if (!modules_dep)
 		fatal("Could not load %s: %s\n",
@@ -314,7 +330,7 @@ static void read_depends(const char *dirname,
 	/* Stop at first line, as we can have duplicates (eg. symlinks
            from boot/ */
 	while (!done && (line = getline_wrapped(modules_dep, NULL)) != NULL) {
-		done = add_modules_dep_line(line, start_name, list);
+		done = add_modules_dep_line(line, start_name, list, dirname);
 		free(line);
 	}
 	fclose(modules_dep);
@@ -348,59 +364,6 @@ static const char *remove_moderror(int err)
 	}
 }
 
-/* Is module in /proc/modules?  If so, fill in usecount if not NULL. 
-   0 means no, 1 means yes, -1 means unknown.
- */
-static int module_in_kernel(const char *modname, unsigned int *usecount)
-{
-	FILE *proc_modules;
-	char *line;
-
-again:
-	/* Might not be mounted yet.  Don't fail. */
-	proc_modules = fopen("/proc/modules", "r");
-	if (!proc_modules)
-		return -1;
-
-	while ((line = getline_wrapped(proc_modules, NULL)) != NULL) {
-		char *entry = strtok(line, " \n");
-
-		if (entry && streq(entry, modname)) {
-			/* If it exists, usecount is the third entry. */
-			if (!strtok(NULL, " \n"))
-				goto out;
-
-			if (!(entry = strtok(NULL, " \n"))) /* usecount */
-				goto out;
-			else
-				if (usecount)
-					*usecount = atoi(entry);
-
-			/* Followed by - then status. */
-			if (strtok(NULL, " \n")
-			    && (entry = strtok(NULL, " \n")) != NULL) {
-				/* Locking will fail on ro fs, we might hit
-				 * cases where module is in flux.  Spin. */
-				if (streq(entry, "Loading")
-				    || streq(entry, "Unloading")) {
-					usleep(100000);
-					free(line);
-					fclose(proc_modules);
-					goto again;
-				}
-			}
-
-		out:
-			free(line);
-			fclose(proc_modules);
-			return 1;
-		}
-		free(line);
-	}
-	fclose(proc_modules);
-	return 0;
-}
-
 static void replace_modname(struct module *module,
 			    void *mem, unsigned long len,
 			    const char *oldname, const char *newname)
@@ -748,6 +711,69 @@ static char *add_extra_options(const char *modname,
 	return optstring;
 }
 
+/* Read sysfs attribute into a buffer.
+ * returns: 1 = ok, 0 = attribute missing,
+ * -1 = file error (or empty file, but we don't care).
+ */
+static int read_attribute(const char *filename, char *buf, size_t buflen)
+{
+	FILE *file;
+	char *s;
+
+	file = fopen(filename, "r");
+	if (file == NULL)
+		return (errno == ENOENT) ? 0 : -1;
+	s = fgets(buf, buflen, file);
+	fclose(file);
+
+	return (s == NULL) ? -1 : 1;
+}
+
+/* Is module in /sys/module?  If so, fill in usecount if not NULL. 
+   0 means no, 1 means yes, -1 means unknown.
+ */
+static int module_in_kernel(const char *modname, unsigned int *usecount)
+{
+	int ret;
+	char *name;
+	struct stat finfo;
+
+	const int ATTR_LEN = 16;
+	char attr[ATTR_LEN];
+
+	/* Find module. We assume sysfs is mounted. */
+	nofail_asprintf(&name, "/sys/module/%s", modname);
+	ret = stat(name, &finfo);
+	free(name);
+	if (ret < 0)
+		return (errno == ENOENT) ? 0 : -1; /* Not found or unknown. */
+
+	/* Wait for the existing module to either go live or disappear. */
+	nofail_asprintf(&name, "/sys/module/%s/initstate", modname);
+	while (1) {
+		ret = read_attribute(name, attr, ATTR_LEN);
+		if (ret != 1 || streq(attr, "live\n"))
+			break;
+
+		usleep(100000);
+	}
+	free(name);
+
+	if (ret != 1)
+		return ret;
+
+	/* Get reference count, if it exists. */
+	if (usecount != NULL) {
+		nofail_asprintf(&name, "/sys/module/%s/refcnt", modname);
+		ret = read_attribute(name, attr, ATTR_LEN);
+		free(name);
+		if (ret == 1)
+			*usecount = atoi(attr);
+	}
+
+	return 1;
+}
+
 /* If we don't flush, then child processes print before we do */
 static void verbose_printf(int verbose, const char *fmt, ...)
 {
@@ -774,10 +800,9 @@ static void do_command(const char *modname,
 
 	while ((p = strstr(replaced_cmd, "$CMDLINE_OPTS")) != NULL) {
 		char *new;
-		asprintf(&new, "%.*s%s%s",
+		nofail_asprintf(&new, "%.*s%s%s",
 			 (int)(p - replaced_cmd), replaced_cmd, cmdline_opts,
 			 p + strlen("$CMDLINE_OPTS"));
-		NOFAIL(new);
 		free(replaced_cmd);
 		replaced_cmd = new;
 	}
@@ -1041,8 +1066,7 @@ static int type_matches(const char *path, const char *subpath)
 	char *subpath_with_slashes;
 	int ret;
 
-	asprintf(&subpath_with_slashes, "/%s/", subpath);
-	NOFAIL(subpath_with_slashes);
+	nofail_asprintf(&subpath_with_slashes, "/%s/", subpath);
 
 	ret = (strstr(path, subpath_with_slashes) != NULL);
 	free(subpath_with_slashes);
@@ -1078,7 +1102,7 @@ static int do_wildcard(const char *dirname,
 		       const char *type,
 		       const char *wildcard)
 {
-	char modules_dep_name[strlen(dirname) + sizeof("modules.dep") + 1];
+	char *modules_dep_name;
 	char *line, *wcard;
 	FILE *modules_dep;
 
@@ -1086,7 +1110,7 @@ static int do_wildcard(const char *dirname,
 	wcard = strdup(wildcard);
 	underscores(wcard);
 
-	sprintf(modules_dep_name, "%s/%s", dirname, "modules.dep");
+	nofail_asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep");
 	modules_dep = fopen(modules_dep_name, "r");
 	if (!modules_dep)
 		fatal("Could not load %s: %s\n",
@@ -1113,6 +1137,7 @@ static int do_wildcard(const char *dirname,
 		free(line);
 	}
 
+	free(modules_dep_name);
 	free(wcard);
 	return 0;
 }
@@ -1269,7 +1294,8 @@ static int read_config(const char *filename,
 	if (dir) {
 		struct dirent *i;
 		while ((i = readdir(dir)) != NULL) {
-			if (!streq(i->d_name,".") && !streq(i->d_name,"..")) {
+			if (!streq(i->d_name,".") && !streq(i->d_name,"..")
+			    && config_filter(i->d_name)) {
 				char sub[strlen(filename) + 1
 					 + strlen(i->d_name) + 1];
 
@@ -1308,7 +1334,7 @@ static int read_config_file_bin(const char *filename,
 	char *binfile;
 	FILE *cfile;
 
-	asprintf(&binfile, "%s.bin", filename);
+	nofail_asprintf(&binfile, "%s.bin", filename);
 	cfile = fopen(binfile, "r");
 	if (!cfile) {
 		free(binfile);
@@ -1416,7 +1442,7 @@ static void add_to_env_var(const char *option)
 
 	if ((oldenv = getenv("MODPROBE_OPTIONS")) != NULL) {
 		char *newenv;
-		asprintf(&newenv, "%s %s", oldenv, option);
+		nofail_asprintf(&newenv, "%s %s", oldenv, option);
 		setenv("MODPROBE_OPTIONS", newenv, 1);
 	} else
 		setenv("MODPROBE_OPTIONS", option, 1);
@@ -1490,6 +1516,11 @@ static void handle_module(const char *modname,
 			  const char *cmdline_opts,
 			  int flags)
 {
+	struct stat finfo;
+
+	if (stat("/sys/module", &finfo) < 0)
+		fatal("/sys is not mounted.\n");
+
 	if (list_empty(todo_list)) {
 		const char *command;
 
@@ -1540,28 +1571,12 @@ static struct option options[] = { { "verbose", 0, NULL, 'v' },
 				   { "force-modversion", 0, NULL, 2 },
 				   { "set-version", 1, NULL, 'S' },
 				   { "show-depends", 0, NULL, 'D' },
+				   { "dirname", 1, NULL, 'd' },
 				   { "first-time", 0, NULL, 3 },
 				   { "dump-modversions", 0, NULL, 4 },
 				   { "use-blacklist", 0, NULL, 'b' },
 				   { NULL, 0, NULL, 0 } };
 
-#define MODPROBE_DEVFSD_CONF "/etc/modprobe.devfs"
-
-/* This is a horrible hack to allow devfsd, which calls modprobe with
-   -C /etc/modules.conf or /etc/modules.devfs, to work.  FIXME. */
-/* Modern devfsd or variants should use -q explicitly in 2.6. */
-static int is_devfs_call(char *argv[])
-{
-	unsigned int i;
-
-	/* Look for "/dev" arg */
-	for (i = 1; argv[i]; i++) {
-		if (strncmp(argv[i], "/dev/", 5) == 0)
-			return 1;
-	}
-	return 0;
-}
-
 int main(int argc, char *argv[])
 {
 	struct utsname buf;
@@ -1584,7 +1599,8 @@ int main(int argc, char *argv[])
 	unsigned int i, num_modules;
 	char *type = NULL;
 	const char *config = NULL;
-	char *dirname, *optstring;
+	char *dirname = NULL;
+	char *optstring = NULL;
 	char *newname = NULL;
 	char *aliasfilename, *symfilename;
 	errfn_t error = fatal;
@@ -1593,17 +1609,8 @@ int main(int argc, char *argv[])
 	/* Prepend options from environment. */
 	argv = merge_args(getenv("MODPROBE_OPTIONS"), argv, &argc);
 
-	/* --set-version overrides version, and disables backwards compat. */
-	for (opt = 1; opt < argc; opt++)
-		if (strncmp(argv[opt],"--set-version",strlen("--set-version"))
-		    == 0)
-			break;
-
-	if (opt == argc)
-		try_old_version("modprobe", argv);
-
 	uname(&buf);
-	while ((opt = getopt_long(argc, argv, "vVC:o:rknqQsclt:aifbw", options, NULL)) != -1){
+	while ((opt = getopt_long(argc, argv, "vVC:o:rknqQsclt:aifbwd:", options, NULL)) != -1){
 		switch (opt) {
 		case 'v':
 			add_to_env_var("-v");
@@ -1617,28 +1624,10 @@ int main(int argc, char *argv[])
 			buf.release[sizeof(buf.release)-1] = '\0';
 			break;
 		case 'C':
-			if (is_devfs_call(argv)) {
-				if (streq("/etc/modules.devfs", optarg)) {
-					config = MODPROBE_DEVFSD_CONF;
-					add_to_env_var("-C");
-					add_to_env_var(config);
-					/* Fall thru to -q */
-				} else if (streq("/etc/modules.conf", optarg))
-					/* Ignore config, fall thru to -q */
-					;
-				else {
-					/* False alarm.  Treat as normal. */
-					config = optarg;
-					add_to_env_var("-C");
-					add_to_env_var(config);
-					break;
-				}
-			} else {
-				config = optarg;
-				add_to_env_var("-C");
-				add_to_env_var(config);
-				break;
-			}
+			config = optarg;
+			add_to_env_var("-C");
+			add_to_env_var(config);
+			break;
 		case 'q':
 			unknown_silent = 1;
 			add_to_env_var("-q");
@@ -1691,6 +1680,10 @@ int main(int argc, char *argv[])
 		case 'w':
 			flags &= ~O_NONBLOCK;
 			break;
+		case 'd':
+			nofail_asprintf(&dirname, "%s/%s/%s", optarg,
+					MODULE_DIR, buf.release);
+			break;
 		case 1:
 			strip_vermagic = 1;
 			break;
@@ -1717,14 +1710,10 @@ int main(int argc, char *argv[])
 	if (argc < optind + 1 && !dump_only && !list_only && !remove)
 		print_usage(argv[0]);
 
-	dirname = NOFAIL(malloc(strlen(buf.release) + sizeof(MODULE_DIR) + 1));
-	sprintf(dirname, "%s/%s", MODULE_DIR, buf.release);
-	aliasfilename = NOFAIL(malloc(strlen(dirname)
-				      + sizeof("/modules.alias")));
-	sprintf(aliasfilename, "%s/modules.alias", dirname);
-	symfilename = NOFAIL(malloc(strlen(dirname)
-				    + sizeof("/modules.symbols")));
-	sprintf(symfilename, "%s/modules.symbols", dirname);
+	if (!dirname)
+		nofail_asprintf(&dirname, "%s/%s", MODULE_DIR, buf.release);
+	nofail_asprintf(&aliasfilename, "%s/modules.alias", dirname);
+	nofail_asprintf(&symfilename, "%s/modules.symbols", dirname);
 
 	/* Old-style -t xxx wildcard?  Only with -l. */
 	if (list_only) {
