@@ -118,19 +118,43 @@ MODTEST_OVERRIDE28=/lib/modules/$MODTEST_UNAME/modules.ofmap
 MODTEST_OVERRIDE_WITH28=tests/tmp/modules.ofmap
 export MODTEST_OVERRIDE28 MODTEST_OVERRIDE_WITH28
 
+MODTEST_OVERRIDE29=/lib/modules/$MODTEST_UNAME/modules.dep.bin
+MODTEST_OVERRIDE_WITH29=tests/tmp/modules.dep.bin
+export MODTEST_OVERRIDE29 MODTEST_OVERRIDE_WITH29
+
+MODTEST_OVERRIDE30=/lib/modules/$MODTEST_UNAME/modules.dep.bin.temp
+MODTEST_OVERRIDE_WITH30=tests/tmp/modules.dep.bin.temp
+export MODTEST_OVERRIDE30 MODTEST_OVERRIDE_WITH30
+
+MODTEST_OVERRIDE31=/lib/modules/$MODTEST_UNAME/modules.alias.bin.temp
+MODTEST_OVERRIDE_WITH31=tests/tmp/modules.alias.bin.temp
+export MODTEST_OVERRIDE31 MODTEST_OVERRIDE_WITH31
+
+MODTEST_OVERRIDE32=/lib/modules/$MODTEST_UNAME/modules.alias.bin
+MODTEST_OVERRIDE_WITH32=tests/tmp/modules.alias.bin
+export MODTEST_OVERRIDE32 MODTEST_OVERRIDE_WITH32
+
+MODTEST_OVERRIDE33=/lib/modules/$MODTEST_UNAME/modules.symbols.bin
+MODTEST_OVERRIDE_WITH33=tests/tmp/modules.symbols.bin
+export MODTEST_OVERRIDE33 MODTEST_OVERRIDE_WITH33
+
+MODTEST_OVERRIDE34=/lib/modules/$MODTEST_UNAME/modules.symbols.bin.temp
+MODTEST_OVERRIDE_WITH34=tests/tmp/modules.symbols.bin.temp
+export MODTEST_OVERRIDE34 MODTEST_OVERRIDE_WITH34
+
 ALL="/lib/modules/$MODTEST_UNAME/export_dep-$BITNESS.ko /lib/modules/$MODTEST_UNAME/noexport_dep-$BITNESS.ko /lib/modules/$MODTEST_UNAME/noexport_nodep-$BITNESS.ko /lib/modules/$MODTEST_UNAME/export_nodep-$BITNESS.ko /lib/modules/$MODTEST_UNAME/noexport_doubledep-$BITNESS.ko"
 
 # Expect no output.
-[ "`depmod $ALL 2>&1`" = "" ]
+[ "`./depmod $ALL 2>&1`" = "" ]
 
 # Check modules.dep results: expect 5 lines
 [ `grep -vc '^#' < tests/tmp/modules.dep` = 5 ]
 
-[ "`grep -w export_dep-$BITNESS.ko: tests/tmp/modules.dep`" = "/lib/modules/$MODTEST_UNAME/export_dep-$BITNESS.ko: /lib/modules/$MODTEST_UNAME/export_nodep-$BITNESS.ko" ]
-[ "`grep -w noexport_dep-$BITNESS.ko: tests/tmp/modules.dep`" = "/lib/modules/$MODTEST_UNAME/noexport_dep-$BITNESS.ko: /lib/modules/$MODTEST_UNAME/export_nodep-$BITNESS.ko" ]
-[ "`grep -w export_nodep-$BITNESS.ko: tests/tmp/modules.dep`" = "/lib/modules/$MODTEST_UNAME/export_nodep-$BITNESS.ko:" ]
-[ "`grep -w noexport_nodep-$BITNESS.ko: tests/tmp/modules.dep`" = "/lib/modules/$MODTEST_UNAME/noexport_nodep-$BITNESS.ko:" ]
-[ "`grep -w noexport_doubledep-$BITNESS.ko: tests/tmp/modules.dep`" = "/lib/modules/$MODTEST_UNAME/noexport_doubledep-$BITNESS.ko: /lib/modules/$MODTEST_UNAME/export_dep-$BITNESS.ko /lib/modules/$MODTEST_UNAME/export_nodep-$BITNESS.ko" ]
+[ "`grep -w export_dep-$BITNESS.ko: tests/tmp/modules.dep`" = "export_dep-$BITNESS.ko: export_nodep-$BITNESS.ko" ]
+[ "`grep -w noexport_dep-$BITNESS.ko: tests/tmp/modules.dep`" = "noexport_dep-$BITNESS.ko: export_nodep-$BITNESS.ko" ]
+[ "`grep -w export_nodep-$BITNESS.ko: tests/tmp/modules.dep`" = "export_nodep-$BITNESS.ko:" ]
+[ "`grep -w noexport_nodep-$BITNESS.ko: tests/tmp/modules.dep`" = "noexport_nodep-$BITNESS.ko:" ]
+[ "`grep -w noexport_doubledep-$BITNESS.ko: tests/tmp/modules.dep`" = "noexport_doubledep-$BITNESS.ko: export_dep-$BITNESS.ko export_nodep-$BITNESS.ko" ]
 
 # Check modules.symbols results: expect 3 lines
 [ `grep -vc '^#' < tests/tmp/modules.symbols` = 3 ]
@@ -143,31 +167,31 @@ mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 
 # Synonyms
-[ "`depmod $MODTEST_UNAME $ALL`" = "" ]
+[ "`./depmod $MODTEST_UNAME $ALL`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep >/dev/null
 mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols >/dev/null
 mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 
-[ "`depmod -e $ALL`" = "" ]
+[ "`./depmod -e $ALL`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep >/dev/null
 mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols >/dev/null
 mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 
-[ "`depmod -e $MODTEST_VERSION $ALL`" = "" ]
+[ "`./depmod -e $MODTEST_VERSION $ALL`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep >/dev/null
 mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols >/dev/null
 mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 
-[ "`depmod --errsyms $ALL`" = "" ]
+[ "`./depmod --errsyms $ALL`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep >/dev/null
 mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols >/dev/null
 mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 
-[ "`depmod --errsyms $MODTEST_VERSION $ALL`" = "" ]
+[ "`./depmod --errsyms $MODTEST_VERSION $ALL`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep >/dev/null
 mv tests/tmp/modules.dep tests/tmp/modules.dep.old
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols >/dev/null
@@ -177,15 +201,15 @@ mv tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 grep -vh '^#' tests/tmp/modules.dep.old tests/tmp/modules.symbols.old > tests/tmp/modules.all.old
 
 # Stdout versions.
-depmod -n $ALL | grep -v '^#' > tests/tmp/modules.all
+./depmod -n $ALL | grep -v '^#' > tests/tmp/modules.all
 diff -u tests/tmp/modules.all.old tests/tmp/modules.all >/dev/null
 mv tests/tmp/modules.all tests/tmp/modules.all.old
 
-depmod -n $MODTEST_VERSION $ALL | grep -v '^#' > tests/tmp/modules.all
+./depmod -n $MODTEST_VERSION $ALL | grep -v '^#' > tests/tmp/modules.all
 diff -u tests/tmp/modules.all.old tests/tmp/modules.all >/dev/null
 mv tests/tmp/modules.all tests/tmp/modules.all.old
 
-depmod -e -n $MODTEST_VERSION $ALL | grep -v '^#' > tests/tmp/modules.all
+./depmod -e -n $MODTEST_VERSION $ALL | grep -v '^#' > tests/tmp/modules.all
 diff -u tests/tmp/modules.all.old tests/tmp/modules.all >/dev/null
 mv tests/tmp/modules.all tests/tmp/modules.all.old
 
