@@ -107,19 +107,68 @@ MODTEST_OVERRIDE10=/lib/modules/$MODTEST_UNAME/modules.dep.bin
 MODTEST_OVERRIDE_WITH10=FILE-WHICH-DOESNT-EXIST
 export MODTEST_OVERRIDE10 MODTEST_OVERRIDE_WITH10
 
-MODTEST_OVERRIDE11=/proc/modules
-MODTEST_OVERRIDE_WITH11=FILE-WHICH-DOESNT-EXIST
+MODTEST_OVERRIDE11=/sys/module/noexport_nodep_$BITNESS
+MODTEST_OVERRIDE_WITH11=tests/tmp/sys/module/noexport_nodep_$BITNESS
 export MODTEST_OVERRIDE11 MODTEST_OVERRIDE_WITH11
 
+MODTEST_OVERRIDE12=/sys/module/noexport_nodep_$BITNESS/initstate
+MODTEST_OVERRIDE_WITH12=tests/tmp/sys/module/noexport_nodep_$BITNESS/initstate
+export MODTEST_OVERRIDE12 MODTEST_OVERRIDE_WITH12
+
+MODTEST_OVERRIDE13=/sys/module/noexport_dep_$BITNESS
+MODTEST_OVERRIDE_WITH13=tests/tmp/sys/module/noexport_dep_$BITNESS
+export MODTEST_OVERRIDE13 MODTEST_OVERRIDE_WITH13
+
+MODTEST_OVERRIDE14=/sys/module/noexport_dep_$BITNESS/initstate
+MODTEST_OVERRIDE_WITH14=tests/tmp/sys/module/noexport_dep_$BITNESS/initstate
+export MODTEST_OVERRIDE14 MODTEST_OVERRIDE_WITH14
+
+MODTEST_OVERRIDE15=/sys/module/export_nodep_$BITNESS
+MODTEST_OVERRIDE_WITH15=tests/tmp/sys/module/export_nodep_$BITNESS
+export MODTEST_OVERRIDE15 MODTEST_OVERRIDE_WITH15
+
+MODTEST_OVERRIDE16=/sys/module/export_nodep_$BITNESS/initstate
+MODTEST_OVERRIDE_WITH16=tests/tmp/sys/module/export_nodep_$BITNESS/initstate
+export MODTEST_OVERRIDE16 MODTEST_OVERRIDE_WITH16
+
+MODTEST_OVERRIDE17=/sys/module/export_dep_$BITNESS
+MODTEST_OVERRIDE_WITH17=tests/tmp/sys/module/export_dep_$BITNESS
+export MODTEST_OVERRIDE17 MODTEST_OVERRIDE_WITH17
+
+MODTEST_OVERRIDE18=/sys/module/export_dep_$BITNESS/initstate
+MODTEST_OVERRIDE_WITH18=tests/tmp/sys/module/export_dep_$BITNESS/initstate
+export MODTEST_OVERRIDE18 MODTEST_OVERRIDE_WITH18
+
+MODTEST_OVERRIDE19=/sys/module/noexport_doubledep_$BITNESS
+MODTEST_OVERRIDE_WITH19=tests/tmp/sys/module/noexport_doubledep_$BITNESS
+export MODTEST_OVERRIDE19 MODTEST_OVERRIDE_WITH19
+
+MODTEST_OVERRIDE20=/sys/module/noexport_doubledep_$BITNESS/initstate
+MODTEST_OVERRIDE_WITH20=tests/tmp/sys/module/noexport_doubledep_$BITNESS/initstate
+export MODTEST_OVERRIDE20 MODTEST_OVERRIDE_WITH20
+
 # Now create modules.dep
 cat > tests/tmp/modules.dep <<EOF
-/lib/modules/2.5.52/noexport_nodep-$BITNESS.ko:
-/lib/modules/2.5.52/noexport_doubledep-$BITNESS.ko: /lib/modules/2.5.52/export_dep-$BITNESS.ko /lib/modules/2.5.52/export_nodep-$BITNESS.ko
-/lib/modules/2.5.52/noexport_dep-$BITNESS.ko: /lib/modules/2.5.52/export_nodep-$BITNESS.ko
-/lib/modules/2.5.52/export_nodep-$BITNESS.ko:
-/lib/modules/2.5.52/export_dep-$BITNESS.ko: /lib/modules/2.5.52/export_nodep-$BITNESS.ko
+noexport_nodep-$BITNESS.ko:
+noexport_doubledep-$BITNESS.ko: export_dep-$BITNESS.ko export_nodep-$BITNESS.ko
+noexport_dep-$BITNESS.ko: export_nodep-$BITNESS.ko
+export_nodep-$BITNESS.ko:
+export_dep-$BITNESS.ko: export_nodep-$BITNESS.ko
 EOF
 
+# Now make a fake /sys/module structure for the test
+mkdir -p tests/tmp/sys/module
+mkdir -p tests/tmp/sys/module/noexport_nodep_$BITNESS
+mkdir -p tests/tmp/sys/module/noexport_dep_$BITNESS
+mkdir -p tests/tmp/sys/module/export_nodep_$BITNESS
+mkdir -p tests/tmp/sys/module/export_dep_$BITNESS
+mkdir -p tests/tmp/sys/module/noexport_doubledep_$BITNESS
+touch tests/tmp/sys/module/noexport_nodep_$BITNESS/initstate
+touch tests/tmp/sys/module/noexport_dep_$BITNESS/initstate
+touch tests/tmp/sys/module/export_nodep_$BITNESS/initstate
+touch tests/tmp/sys/module/export_dep_$BITNESS/initstate
+touch tests/tmp/sys/module/noexport_doubledep_$BITNESS/initstate
+
 SIZE_NOEXPORT_NODEP=$(echo `wc -c < tests/data/$BITNESS/normal/noexport_nodep-$BITNESS.ko`)
 SIZE_EXPORT_NODEP=$(echo `wc -c < tests/data/$BITNESS/normal/export_nodep-$BITNESS.ko`)
 SIZE_NOEXPORT_DEP=$(echo `wc -c < tests/data/$BITNESS/normal/noexport_dep-$BITNESS.ko`)
